@@ -3,18 +3,22 @@ Main interface for savingsplans service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.savingsplans import (
+    from mypy_boto3_savingsplans import (
         Client,
         SavingsPlansClient,
-        )
+    )
 
     session = boto3.Session()
 
     client: SavingsPlansClient = boto3.client("savingsplans")
     session_client: SavingsPlansClient = session.client("savingsplans")
+    ```
 """
-from mypy_boto3_savingsplans.client import SavingsPlansClient as Client, SavingsPlansClient
+from mypy_boto3_savingsplans.client import SavingsPlansClient
+
+Client = SavingsPlansClient
 
 
 __all__ = ("Client", "SavingsPlansClient")
